#install.sh
#===============================================================================================
# Spreader Report Configuration for Cirus Controller
# This assumes that you already have a GPSReport configure for reporting GPSData.  
#
# NOTE: Ensure that there is space available in the requested GPSReport to add in the PCYP message
#	( ie less than 4 have already been added ) when using gpsaddmes
#
# 	SPREADER_GPS_REPORT 		=> The already configured GPSCondition report to use.
#	SPREADER_GPS_REPORT_SCRIPT 	=> The matching report script to call
# 
# Also sets up the PCYP String
# ****** CONFIGURE SETTINGS HEARE ****************
#===============================================================================================
SPREADER_GPS_REPORT=1                           # GPS Report to trigger spreader app to run
SPREADER_GPS_REPORT_SCRIPT=report1020.sh        # Report Script to run spreader app
SPREADER_PCYP_STRING=1000			# Set the PCYP id to use.

SPREADER_SERIAL_READ_REPORT=20			# Report number that cats the serial port
SPREADER_SERIAL_READ_SCRIPT=report20.sh		# Script to run when catting the port

SPREADER_SERIAL_READ_VCC_TRIGGER=2		# VCC trigger number to monitor ignition on. 
SPREADER_SERIAL_POLL_RATE=35			# Poll rate while VCC on to tigger the read port script.
#--------------------------------------------------------------------------------------------------



#--------------------------------------------------------------------------------------------------
# Report Script Configuration and file copy to SD card 
#--------------------------------------------------------------------------------------------------
MYPATH="/tmp/spreader"
dos2unix $MYPATH/spreader.py
dos2unix $MYPATH/$SPREADER_GPS_REPORT_SCRIPT
dos2unix $MYPATH/$SPREADER_SERIAL_READ_SCRIPT


cp $MYPATH/spreader.py /var/data/reports/scripts/
cp $MYPATH/$SPREADER_GPS_REPORT_SCRIPT /var/data/reports/scripts/
cp $MYPATH/$SPREADER_SERIAL_READ_SCRIPT /var/data/reports/scripts/

chmod u+x /var/data/reports/scripts/$SPREADER_GPS_REPORT_SCRIPT
chmod u+x /var/data/reports/scripts/$SPREADER_SERIAL_READ_SCRIPT
#--------------------------------------------------------------------------------------------------

#--------------------------------------------------------------------------------------------------
# CTM Config
#--------------------------------------------------------------------------------------------------
cmd mode 0
cmd reportscripts 1                     # Trigger report to run reportXX scripts
#--------------------------------------------------------------------------------------------------



#--------------------------------------------------------------------------------------------------
#Configure CTM-200 Report Conditions
#--------------------------------------------------------------------------------------------------

# Spreader Report
cmd gpsaddmes $SPREADER_GPS_REPORT $SPREADER_PCYP_STRING     						# PGPS and PCYP to the report

# VCC report to poll serial port.
cmd vccreport $SPREADER_SERIAL_READ_VCC_TRIGGER $SPREADER_SERIAL_READ_REPORT 0 0 0 0 0 0 0		# Setup vcc trigger to a custom report 
cmd vcccond $SPREADER_SERIAL_READ_VCC_TRIGGER 2 8.0 $SPREADER_SERIAL_POLL_RATE				# set VCC condition to how often it triggers
#---------------------------------------------------------------------


#---------------------------------------------------------------------
# PCYP Configuration
# USR_STR 1-3 [ Spreader data ]
# USR_STR 4 [ Raw Data (off by default)
# GPIO 1-4 [ Input Status ]
# VEH_IGN  [ Ignition Status ]
#---------------------------------------------------------------------
cmd pcyp msg add $SPREADER_PCYP_STRING USR_STR_1
cmd pcyp msg add $SPREADER_PCYP_STRING USR_STR_2
cmd pcyp msg add $SPREADER_PCYP_STRING USR_STR_3
cmd pcyp msg add $SPREADER_PCYP_STRING USR_FLT_9
#cmd pcyp msg add $SPREADER_PCYP_STRING USR_STR_4

cmd pcyp msg add $SPREADER_PCYP_STRING GPIO_DIN1
cmd pcyp msg add $SPREADER_PCYP_STRING GPIO_DIN2
cmd pcyp msg add $SPREADER_PCYP_STRING GPIO_DIN3
cmd pcyp msg add $SPREADER_PCYP_STRING GPIO_DIN4
cmd pcyp msg add $SPREADER_PCYP_STRING VEH_IGN
#---------------------------------------------------------------------


cmd save
cmd event add Cirus_INSTALL_OK
